# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_list_category import ResponseWrapperListCategory

class TestResponseWrapperListCategory(unittest.TestCase):
    """ResponseWrapperListCategory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListCategory:
        """Test ResponseWrapperListCategory
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListCategory`
        """
        model = ResponseWrapperListCategory()
        if include_optional:
            return ResponseWrapperListCategory(
                done = True,
                result = [
                    public_api_server_connector_v2.models.category.Category(
                        name = '', 
                        create = public_api_server_connector_v2.models.category_method_options.CategoryMethodOptions(
                            available = True, 
                            available_endpoint_count = 56, ), 
                        read = public_api_server_connector_v2.models.category_method_options.CategoryMethodOptions(
                            available = True, 
                            available_endpoint_count = 56, ), 
                        update = , 
                        delete = , )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListCategory(
                done = True,
        )
        """

    def testResponseWrapperListCategory(self):
        """Test ResponseWrapperListCategory"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
